==> OmegaT_2.0.5_02_Source.zip: src/org/omegat/core/events/IEntryEventListener.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **************************************************************************/
package org.omegat.core.events;

import org.omegat.core.data.StringEntry;

/**
 * Listener interface for entry change events.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public interface IEntryEventListener {
    /**
     * Called on new file displayed.
     * 
     * @param activeFileName
     *            new active file name
     */
    void onNewFile(String activeFileName);

    /**
     * Called on new entry activated or current entry deactivated.
     * 
     * @param newEntry
     *            new entry instance which activated, or null if entry
     *            deactivated
     */
    void onEntryActivated(StringEntry newEntry);
}

==> OmegaT_2.6.3_01_Source.zip: src/org/omegat/core/events/IEntryEventListener.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool 
          with fuzzy matching, translation memory, keyword search, 
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2008 Alex Buloichik
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 **************************************************************************/
package org.omegat.core.events;

import org.omegat.core.data.SourceTextEntry;

/**
 * Listener interface for entry change events.
 * 
 * @author Alex Buloichik (alex73mail@gmail.com)
 */
public interface IEntryEventListener {
    /**
     * Called on new file displayed.
     * 
     * @param activeFileName
     *            new active file name
     */
    void onNewFile(String activeFileName);

    /**
     * Called on new entry activated or current entry deactivated.
     * 
     * @param newEntry
     *            new entry instance which activated, or null if entry
     *            deactivated
     */
    void onEntryActivated(SourceTextEntry newEntry);
}
